diff --git a/source/RobotAPI/libraries/Controllers/RobotUnit.cpp b/source/RobotAPI/libraries/Controllers/RobotUnit.cpp
index 8fcc18853926f6247f11471a9dbfa7c37d19b72e..f612bf99b6088d9ea2edc071c572a7da37507239 100644
--- a/source/RobotAPI/libraries/Controllers/RobotUnit.cpp
+++ b/source/RobotAPI/libraries/Controllers/RobotUnit.cpp
@@ -164,8 +164,8 @@ void armarx::RobotUnit::switchSetup(const Ice::StringSeq& controllerRequestedNam
     {
         if (!hasLVL1Controller(lvl1))
         {
-            ARMARX_ERROR << "No controler of the name '" << lvl1 << "' is loaded!";
-            throw InvalidArgumentException {"No controler of the name '" + lvl1 + "' is loaded!"};
+            ARMARX_ERROR << "No controller of the name '" << lvl1 << "' is loaded!";
+            throw InvalidArgumentException {"No controller of the name '" + lvl1 + "' is loaded!"};
         }
     }
     //check controllers (is there a collision/which controllers need to be deactivated)
@@ -276,7 +276,7 @@ armarx::LVL1ControllerInterfacePrx armarx::RobotUnit::loadController(const std::
         ARMARX_ERROR << ss.str();
         throw InvalidArgumentException {ss.str()};
     }
     //create the controler
     jointsUsedByLVL1Controler.clear();
     LVL1ControllerPtr lvl1 = factory(this, config);
     lvl1->jointControlModeMap = jointsUsedByLVL1Controler;
@@ -276,7 +276,7 @@ armarx::LVL1ControllerInterfacePrx armarx::RobotUnit::loadController(const std::
         throw InvalidArgumentException {ss.str()};
     }
-    //create the controler
+    //create the controller
     jointsUsedByLVL1Controler.clear();
     LVL1ControllerPtr lvl1 = factory(this, config);